@@ -24,8 +24,8 @@ Check the HTTP status for a resource.
 
 =cut
 
-use v5.10.1;  # Mojolicious is v5.10.1 and later
-our $VERSION = '2.08';
+use v5.10.1;	# Mojolicious is v5.10.1 and later
+our $VERSION = '2.09';
 
 use parent 'Test::Builder::Module';
 
@@ -194,19 +194,25 @@ sub _check_link {
 	my $transaction = $UA->head($link);
 	my $response = $transaction->res();
 
-	if( !($response and $response->code >= 400) ) {
+	if(($response && ($response->code() >= 400))) {
 		$transaction = $UA->get($link);
 		$response = $transaction->res;
-		}
+	}
 
-	unless( ref $response ) {
+	unless(ref($response)) {
 		# $ERROR = 'Could not get response';
 		return;
-		}
+	}
 
-	return $response->code;
+	return $response->code();
 }
 
+=head2 user_agent
+
+Returns the user agent being used
+
+=cut
+
 sub user_agent { $UA }
 
 =head1 SEE ALSO
@@ -221,6 +227,8 @@ Maintained by Nigel Horne, C<< <njh at bandsman.co.uk> >>
 
 =head1 SUPPORT
 
+This module is provided as-is without any warranty.
+
 You can find documentation for this module with the perldoc command.
 
     perldoc Test::HTTPStatus
